@@ -18,12 +18,12 @@
 """Utility functions for dealing with Debian Vcs URLs of various types."""
 
 __all__ = [
-    'split_vcs_url',
-    'unsplit_vcs_url',
-    'get_vcs_info',
-    'mangle_version_for_git',
-    'source_package_vcs',
-    'gbp_expand_tag_name',
+    "split_vcs_url",
+    "unsplit_vcs_url",
+    "get_vcs_info",
+    "mangle_version_for_git",
+    "source_package_vcs",
+    "gbp_expand_tag_name",
 ]
 
 import re
@@ -31,7 +31,6 @@ from typing import NamedTuple, Optional, Tuple
 
 
 class VcsUrl(NamedTuple):
-
     url: str
     branch: Optional[str]
     path: Optional[str]
@@ -50,23 +49,23 @@ def split_vcs_url(url: str) -> VcsUrl:
     """
     subpath: Optional[str]
     branch: Optional[str]
-    m = re.search(r' \[([^] ]+)\]', url)
+    m = re.search(r" \[([^] ]+)\]", url)
     if m:
-        url = url[:m.start()] + url[m.end():]
+        url = url[: m.start()] + url[m.end() :]
         subpath = m.group(1)
     else:
         subpath = None
     try:
-        (repo_url, branch) = url.split(' -b ', 1)
+        (repo_url, branch) = url.split(" -b ", 1)
     except ValueError:
         branch = None
         repo_url = url
     return VcsUrl(repo_url, branch, subpath)
 
 
-def unsplit_vcs_url(repo_url: str,
-                    branch: Optional[str] = None,
-                    subpath: Optional[str] = None) -> str:
+def unsplit_vcs_url(
+    repo_url: str, branch: Optional[str] = None, subpath: Optional[str] = None
+) -> str:
     """Unsplit a Debian VCS URL.
 
     Args:
@@ -77,14 +76,13 @@ def unsplit_vcs_url(repo_url: str,
     """
     url = repo_url
     if branch:
-        url = '{} -b {}'.format(url, branch)
+        url = f"{url} -b {branch}"
     if subpath:
-        url = '{} [{}]'.format(url, subpath)
+        url = f"{url} [{subpath}]"
     return url
 
 
-def get_vcs_info(control) -> Tuple[
-        Optional[str], Optional[str], Optional[str]]:
+def get_vcs_info(control) -> Tuple[Optional[str], Optional[str], Optional[str]]:
     if "Vcs-Git" in control:
         repo_url, branch, subpath = split_vcs_url(control["Vcs-Git"])
         return ("Git", repo_url, subpath)
@@ -110,12 +108,11 @@ def mangle_version_for_git(version: str) -> str:
     Returns: tag name
     """
     # See https://dep-team.pages.debian.net/deps/dep14/
-    manipulated = (
-        version.replace("~", "_").replace(':', '%').replace('..', '.#.'))
-    if manipulated.endswith('.'):
-        manipulated += '#'
-    if manipulated.endswith('.lock'):
-        manipulated = manipulated[:-4] + '#lock'
+    manipulated = version.replace("~", "_").replace(":", "%").replace("..", ".#.")
+    if manipulated.endswith("."):
+        manipulated += "#"
+    if manipulated.endswith(".lock"):
+        manipulated = manipulated[:-4] + "#lock"
     return manipulated
 
 
@@ -129,11 +126,11 @@ def source_package_vcs(control) -> Tuple[str, str]:
     Raises:
       KeyError: When no Vcs header was found
     """
-    for prefix in ['Vcs-', 'XS-Vcs-', 'X-Vcs']:
+    for prefix in ["Vcs-", "XS-Vcs-", "X-Vcs"]:
         for field, value in control.items():
             if field.startswith(prefix):
-                vcs_type = field[len(prefix):]
-                if vcs_type == 'Browser':
+                vcs_type = field[len(prefix) :]
+                if vcs_type == "Browser":
                     continue
                 return vcs_type, value
     raise KeyError
@@ -150,22 +147,17 @@ class GbpTagFormatError(Exception):
 
 def gbp_expand_tag_name(tag_format: str, version: str) -> str:
     # See gbp/pkg/pkgpolicy.py in gbp-buildpackage
-    version_mangle_re = (
-        r'%\(version'
-        r'%(?P<M>[^%])'
-        r'%(?P<R>([^%]|\\%))+'
-        r'\)s')
+    version_mangle_re = r"%\(version" r"%(?P<M>[^%])" r"%(?P<R>([^%]|\\%))+" r"\)s"
 
     ret = tag_format
     m = re.search(version_mangle_re, tag_format)
     if m:
         ret = re.sub(version_mangle_re, "%(version)s", tag_format)
-        version = version.replace(
-            m.group('M'), m.group('R').replace(r'\%', '%'))
+        version = version.replace(m.group("M"), m.group("R").replace(r"\%", "%"))
 
     vars = {
-        'version': version,
-        'hversion': version.replace('.', '-'),
+        "version": version,
+        "hversion": version.replace(".", "-"),
     }
     try:
         return ret % vars
